pub struct QuantifierN<I: HaystackItem, A: Matcher<I>, const N: usize>(pub PhantomData<I>, pub PhantomData<A>);Tuple Fields
0: PhantomData<I>1: PhantomData<A>Trait Implementations
Sourceimpl<I: HaystackItem, A: Matcher<I>, const N: usize> Debug for QuantifierN<I, A, N>
impl<I: HaystackItem, A: Matcher<I>, const N: usize> Debug for QuantifierN<I, A, N>
Sourceimpl<I: Default + HaystackItem, A: Default + Matcher<I>, const N: usize> Default for QuantifierN<I, A, N>
impl<I: Default + HaystackItem, A: Default + Matcher<I>, const N: usize> Default for QuantifierN<I, A, N>
Sourcefn default() -> QuantifierN<I, A, N>
fn default() -> QuantifierN<I, A, N>
Returns the “default value” for a type. Read more
Sourceimpl<I: HaystackItem, A: Matcher<I>, const N: usize> Matcher<I> for QuantifierN<I, A, N>
impl<I: HaystackItem, A: Matcher<I>, const N: usize> Matcher<I> for QuantifierN<I, A, N>
Sourcefn matches<'a, H: HaystackOf<'a, I>>(hay: &mut H) -> bool
fn matches<'a, H: HaystackOf<'a, I>>(hay: &mut H) -> bool
Checks if the start of the haystack contains a match for this
Matcher. If this method
successfully matches the start of the haystack, hay is progressed so that hay.item()
hasn’t been matched yet. On a fail, the state of hay is undefined.Sourcefn captures<'a, H: HaystackOf<'a, I>>(
hay: &mut H,
caps: &mut IndexedCaptures,
) -> bool
fn captures<'a, H: HaystackOf<'a, I>>( hay: &mut H, caps: &mut IndexedCaptures, ) -> bool
Sourcefn all_matches<'a, H: HaystackOf<'a, I>>(hay: &mut H) -> Vec<usize>
fn all_matches<'a, H: HaystackOf<'a, I>>(hay: &mut H) -> Vec<usize>
Produces a Vec of all valid haystack states produced as the result of a valid match at the
start of
hay, used to implement backtracking. The Vec is produced in reverse priority
order, so the last match has the highest priority. After calling all_matches, the state of
hay itself is undefined. Read moreSourcefn all_captures<'a, H: HaystackOf<'a, I>>(
hay: &mut H,
caps: &mut IndexedCaptures,
) -> Vec<(usize, IndexedCaptures)>
fn all_captures<'a, H: HaystackOf<'a, I>>( hay: &mut H, caps: &mut IndexedCaptures, ) -> Vec<(usize, IndexedCaptures)>
Produces a Vec of all valid captures (and accompanying haystack states) present at the start
of
hay. Used to implement backtracking for capturing methods. As with
all_matches, the resulting Vec is produced in reverse priority
order. After calling all_captures, the state of hay and caps are undefined. Read moreAuto Trait Implementations
impl<I, A, const N: usize> Freeze for QuantifierN<I, A, N>
impl<I, A, const N: usize> RefUnwindSafe for QuantifierN<I, A, N>
impl<I, A, const N: usize> Send for QuantifierN<I, A, N>
impl<I, A, const N: usize> Sync for QuantifierN<I, A, N>
impl<I, A, const N: usize> Unpin for QuantifierN<I, A, N>
impl<I, A, const N: usize> UnwindSafe for QuantifierN<I, A, N>